import 'package:arupo_shop/constants/constants.dart';
import 'package:arupo_shop/utils/responsive.dart';
import 'package:arupo_shop/view_models/auth_view_model.dart';
import 'package:arupo_shop/view_models/request_detaill_view_model2.dart';
import 'package:arupo_shop/view_models/request_view_model.dart';
import 'package:arupo_shop/widgets/icon_text_button.dart';
import 'package:arupo_shop/widgets/item_list.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class RequestPanel extends StatelessWidget {
  const RequestPanel({Key? key}) : super(key: key);

  _snackBar(BuildContext context, String text) {
    final snackBar = SnackBar(
      content: Text(text),
      action: SnackBarAction(
        label: '',
        onPressed: () {
          // Some code to undo the change.
        },
      ),
    );
    ScaffoldMessenger.of(context).showSnackBar(snackBar);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      constraints: BoxConstraints(
        minWidth: 250,
        maxWidth: Responsive.istablet ? 430 : 350,
      ),
      child: Column(
        children: [
          Padding(
            padding: EdgeInsets.all(Responsive.hp(2)),
            child: Text(
              "CREANDO SOLICITUD",
              style: TextStyle(
                color: Colors.teal,
                fontWeight: FontWeight.bold,
              ),
            ),
          ),
          Padding(
              padding: EdgeInsets.symmetric(
                horizontal: Responsive.wp(5),
              ),
              child: IconTextButton(
                icon: Icon(
                  Icons.shopping_cart,
                  color: Colors.yellow[700],
                ),
                label: 'Añadir Items',
                radius: Responsive.dp(2),
                onChanged: () {
                  Navigator.of(context).pushNamed(ITEM_ADD_SCREEN);
                },
              )),
          Padding(
            padding: EdgeInsets.all(Responsive.hp(3)),
            child: Text("Items en esta solicitud: "),
          ),
          Padding(
            padding: EdgeInsets.symmetric(horizontal: Responsive.wp(5)),
            child: Container(
              height: Responsive.hp(45),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(10),
                color: Colors.white,
              ),
              child: ItemList(),
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(20.0),
            child: SizedBox(
              width: double.infinity,
              height: 45,
              child: Consumer3<RequestDetailViewModel2, RequestViewModel,
                  AuthViewModel>(
                builder: (
                  context,
                  requestDetailVM,
                  requestVM,
                  authVM,
                  child,
                ) =>
                    TextButton(
                  style: ButtonStyle(
                    backgroundColor: MaterialStateProperty.all(
                      Colors.teal,
                    ),
                    shape: MaterialStateProperty.all(
                      RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(25.0),
                      ),
                    ),
                  ),
                  onPressed: () async {
                    if (requestDetailVM.getItems.isNotEmpty) {
                      await authVM.checkIfLogin();
                      if (authVM.isAuthenticated) {
                        int idRequest = await requestVM.createRequest(
                          authVM.account,
                          requestDetailVM.getItems,
                        );
                        if (idRequest > 0) {
                          //Clear form
                          requestDetailVM.removeAll();
                          _snackBar(context, "REGISTRO EXITOSO");
                        } else {
                          _snackBar(context, "ERROR AL REGISTRAR LA SOLICITUD");
                        }
                      } else {
                        Navigator.of(context).pushReplacementNamed(SIGN_IN);
                      }
                    } else {
                      _snackBar(context, "SOLICITUD SIN ITEMS");
                    }
                  },
                  child: Text(
                    "REGISTRAR SOLICITUD",
                    style: TextStyle(color: Colors.white),
                  ),
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}
