import 'dart:async';

import 'package:arupo_shop/constants/constants.dart';
import 'package:arupo_shop/utils/responsive.dart';
import 'package:arupo_shop/view_models/auth_view_model.dart';
import 'package:arupo_shop/widgets/logo_dev.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:provider/provider.dart';

class AnimatedSplashScreen extends StatefulWidget {
  @override
  _SplashScreenState createState() => new _SplashScreenState();
}

class _SplashScreenState extends State<AnimatedSplashScreen>
    with SingleTickerProviderStateMixin {
  var _visible = true;
  late AnimationController animationController;
  late Animation<double> animation;
  late AuthViewModel authViewModel;

  startTime(AuthViewModel authViewModel) async {
    var _duration = new Duration(seconds: 3);
    await Future.delayed(_duration);
    //Check security
    await authViewModel.checkIfLogin();
    if (authViewModel.isAuthenticated) {
      if (authViewModel.account.credentials.length > 1) {
        Navigator.of(context).pushNamedAndRemoveUntil(
            ROLE_SCREEN, (Route<dynamic> route) => false);
      } else {
        String roleName = authViewModel.account.credentials[0].role.description;
        if (roleName == 'COMPRADOR') {
          Navigator.of(context).pushReplacementNamed(HOME_BUYER);
        } else {
          Navigator.of(context).pushReplacementNamed(HOME_SELLER);
        }
      }
    } else {
      Navigator.of(context).pushReplacementNamed(SIGN_IN);
    }
  }

  @override
  void initState() {
    SystemChrome.setSystemUIOverlayStyle(SystemUiOverlayStyle(
      statusBarColor: Colors.transparent,
    ));
    super.initState();
    animationController = new AnimationController(
      vsync: this,
      duration: new Duration(seconds: 3),
    );
    animation = new CurvedAnimation(
      parent: animationController,
      curve: Curves.easeOut,
    );
    animation.addListener(() => this.setState(() {}));
    animationController.forward();
    setState(() {
      _visible = !_visible;
    });
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {
      authViewModel = Provider.of<AuthViewModel>(context, listen: false);
      startTime(authViewModel);
    });
  }

  @override
  void dispose() {
    SystemChrome.setEnabledSystemUIMode(SystemUiMode.manual, overlays: [
      SystemUiOverlay.bottom,
      SystemUiOverlay.top,
    ]);
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    //final Responsive responsive = Responsive.of(context);
    Responsive.of(context);
    return Scaffold(
      body: Container(
        color: Colors.lime[100],
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: <Widget>[
            Expanded(
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[
                  Image.asset(
                    'assets/images/logo_arupo.png',
                    width: animation.value * Responsive.wp(60),
                    height: animation.value * Responsive.hp(30),
                  ),
                ],
              ),
            ),
            LogoDevWidget(
              label: 'Developed by:',
              imagePath: 'assets/images/logo_ct.png',
            )
          ],
        ),
      ),
    );
  }
}
