import 'dart:convert';

import 'package:arupo_shop/constants/constants.dart';
import 'package:arupo_shop/models/buyer.dart';
import 'package:arupo_shop/models/request.dart';
import 'package:http/http.dart' as http;

class RequestService {
  Future<String?> createRequest(Request request) async {
    Map<String, String> headers = {'Content-Type': 'application/json'};
    var response = await http.post(
      Uri.parse('$API_URL/requests'),
      headers: headers,
      body: jsonEncode(request.toJson()),
    );
    if (response.statusCode == 201) {
      var data = response.headers;
      return data['location'];
    } else {
      throw Exception('Failed to create REQUEST');
    }
  }

  Future<List<Request>> getRequestListByBuyer(Buyer buyer) async {
    Map<String, String> headers = {"Accept": "Application/json; charset=utf-8"};
    String email = buyer.account.email;
    var response = await http.get(
      Uri.parse('$API_URL/requests/buyer/$email'),
      headers: headers,
    );
    if (response.statusCode == 200) {
      var data = jsonDecode(response.body);
      final userdata = new List<Map<String, dynamic>>.from(data);
      List<Request> requests = userdata.map((f) => Request.fromMap(f)).toList();
      return requests;
    } else {
      throw Exception('Failed to get REQUESTS data');
    }
  }

  Future<bool> deleteRequest(Request request) async {
    var response = await http.delete(
      Uri.parse('$API_URL/requests/${request.id}'),
    );
    if (response.statusCode == 200) {
      return true;
    } else if (response.statusCode == 304) {
      return false;
    } else {
      throw Exception('Failed to DELETE REQUEST');
    }
  }
}
