import 'package:arupo_shop/data/auth_data_client.dart';
import 'package:arupo_shop/models/account.dart';
import 'package:arupo_shop/models/credential.dart';
import 'package:arupo_shop/models/jwt.dart';
import 'package:arupo_shop/models/role.dart';
import 'package:arupo_shop/repositories/auth_repository.dart';
import 'package:arupo_shop/utils/jwt_decode.dart';
import 'package:arupo_shop/utils/time.dart';
import 'package:flutter/material.dart';

class AuthViewModel with ChangeNotifier {
  late Account account;
  late String authToken;
  late String refreshToken;
  late int expiration;
  late bool isAuthenticated = false;

  //Sign in method
  Future<void> signIn(String username, String password) async {
    this.isAuthenticated = false;
    account = Account(
      email: username,
      password: password,
      credentials: [],
      id: 0,
    );
    JWT jwt = await AuthRepository().signIn(account);
    String token = jwt.token;
    // Check JWT has valid token, not
    if (token.trim().length > 0) {
      _updateAuthData(jwt);
      //Save JWT
      await AuthDataClient().saveToken(jwt);
    }
  }

  //Logout
  Future<void> signOut() async {
    this.isAuthenticated = false;
    await AuthDataClient().deleteToken();
  }

  //Refresh token
  Future<void> refreshAuthToken() async {
    print("TRYING REFRESH");
    this.isAuthenticated = false;
    JWT jwt = await AuthRepository().refreshToken(this.refreshToken);
    String token = jwt.token;
    // Check JWT has valid token, not
    if (token.trim().length > 0) {
      _updateAuthData(jwt);
      //Save JWT
      await AuthDataClient().saveToken(jwt);
    }
  }

  //Check if token data is saved on file
  Future<void> checkIfLogin() async {
    JWT jwt = await AuthDataClient().accessToken;
    if (jwt.token.trim().length > 0) {
      _updateAuthData(jwt);
      if (isValidSession() == false) {
        await refreshAuthToken();
      }
    }
  }

  //Check token expiration
  bool isValidSession() {
    bool sessionValid = false;
    int remaining = this.expiration - Time().nowTimeStamp();
    print(remaining);
    if (remaining > 120) {
      sessionValid = true;
    }
    return sessionValid;
  }

  //Update variable data
  void _updateAuthData(JWT jwt) {
    this.refreshToken = jwt.refresh;
    this.authToken = jwt.token.split(' ')[1];
    var payload = JWTDecode().parseJwt(this.authToken);
    //Create Account with payload
    this.account = Account(
      email: payload['sub'],
      password: '',
      credentials: [],
      id: 0,
    );
    this.account.credentials = _getCredentialsFromRolesString(payload['roles']);
    this.expiration = payload['exp'];
    this.isAuthenticated = true;
    notifyListeners();
    print(payload);
  }

  List<Credential> _getCredentialsFromRolesString(String rolesString) {
    List<Credential> listCredentials = [];
    List<String> roles = rolesString.split(',');
    for (String roleName in roles) {
      Role _role = new Role(
        description: roleName.trim(),
        id: 0,
      );
      Credential _credential = Credential(role: _role);
      listCredentials.add(_credential);
    }
    return listCredentials;
  }
}
