import 'package:arupo_shop/models/category.dart';
import 'package:arupo_shop/view_models/category_view_model.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class CategorySpinner extends StatelessWidget {
  const CategorySpinner({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        Padding(
          padding: const EdgeInsets.all(8.0),
          child: new Text(
            "Seleccione una categoría: ",
            style: TextStyle(
              fontSize: 16.0,
            ),
          ),
        ),
        Consumer<CategoryViewModel>(builder: (context, model, child) {
          return FutureBuilder<List<Category>>(
              future: model.fetchCategories(),
              builder: (BuildContext context,
                  AsyncSnapshot<List<Category>> snapshot) {
                if (!snapshot.hasData) return CircularProgressIndicator();

                return Container(
                  //width: 300,
                  padding: EdgeInsets.symmetric(vertical: 0, horizontal: 35),
                  decoration: BoxDecoration(
                    //color: Colors.teal,
                    border: Border.all(color: Colors.teal),
                    borderRadius: BorderRadius.circular(30),
                  ),
                  child: DropdownButton(
                    items: snapshot.data!
                        .map(
                          (category) => DropdownMenuItem(
                            child: Text(
                              category.description,
                              style: TextStyle(
                                color: Colors.pinkAccent,
                              ),
                            ),
                            value: category.id,
                          ),
                        )
                        .toList(),
                    isExpanded: true,
                    value: model.categoryIdSelected,
                    // Hide the default underline
                    underline: Container(),

                    onChanged: (value) {
                      model.selectCategory(value);
                    },
                  ),
                );
              });
        }),
        SizedBox(height: 20.0),
      ],
    );
  }
}
