import 'package:flutter/material.dart';

class InputText extends StatelessWidget {
  final String value;
  final String label;
  final TextInputType? keyboardType;
  final bool obscuredText;
  final bool borderEnabled;
  final double fontSize;
  final void Function(String text) onChanged;
  final String? Function(String? text)? validator;

  const InputText(
      {Key? key,
      this.value = '',
      this.label = '',
      this.keyboardType = TextInputType.text,
      this.obscuredText = false,
      this.borderEnabled = true,
      this.fontSize = 15,
      required this.onChanged,
      this.validator})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      initialValue: value,
      keyboardType: this.keyboardType,
      obscureText: this.obscuredText,
      decoration: InputDecoration(
        labelStyle: TextStyle(
          fontSize: this.fontSize,
        ),
        labelText: label,
        enabledBorder: this.borderEnabled
            ? UnderlineInputBorder(
                borderSide: BorderSide(
                  color: Colors.teal,
                ),
              )
            : InputBorder.none,
      ),
      onChanged: this.onChanged,
      validator: this.validator,
    );
  }
}
