import 'package:arupo_shop/models/item.dart';
import 'package:arupo_shop/utils/responsive.dart';
import 'package:arupo_shop/view_models/category_view_model.dart';
import 'package:arupo_shop/view_models/item_view_model.dart';
import 'package:arupo_shop/view_models/request_detaill_view_model2.dart';
import 'package:arupo_shop/widgets/category_spinner.dart';
import 'package:arupo_shop/widgets/icon_text_button.dart';
import 'package:arupo_shop/widgets/input_text.dart';
import 'package:arupo_shop/widgets/item_detail_panel.dart';
import 'package:arupo_shop/widgets/item_quantity.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class ItemRequestForm extends StatefulWidget {
  const ItemRequestForm({Key? key}) : super(key: key);

  @override
  _ItemRequestFormState createState() => _ItemRequestFormState();
}

class _ItemRequestFormState extends State<ItemRequestForm> {
  static GlobalKey<FormState> _formKey = GlobalKey();
  static GlobalKey<FormState> _formItemDetailKey = GlobalKey();

  _snackBar(String text) {
    final snackBar = SnackBar(
      content: Text(text),
      action: SnackBarAction(
        label: '',
        onPressed: () {
          // Some code to undo the change.
        },
      ),
    );
    ScaffoldMessenger.of(context).showSnackBar(snackBar);
  }

  _itemDetailDialogForm() {
    String _detailDescription = "";
    String _detailValue = "";
    showDialog(
        context: context,
        builder: (BuildContext context) {
          return AlertDialog(
            content: Stack(
              clipBehavior: Clip.none,
              children: <Widget>[
                Positioned(
                  right: -40.0,
                  top: -40.0,
                  child: InkResponse(
                    onTap: () {
                      Navigator.of(context).pop();
                    },
                    child: CircleAvatar(
                      child: Icon(
                        Icons.cancel_outlined,
                        color: Colors.white,
                      ),
                      backgroundColor: Colors.pinkAccent,
                    ),
                  ),
                ),
                Form(
                  key: _formItemDetailKey,
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    children: <Widget>[
                      Padding(
                        padding: EdgeInsets.all(8.0),
                        child: InputText(
                          label: 'Descripción:',
                          fontSize:
                              Responsive.dp(Responsive.istablet ? 1.2 : 1.6),
                          onChanged: (String text) {
                            _detailDescription = text;
                          },
                          validator: (text) {
                            if (text!.length == 0) {
                              return "* Campo requerido";
                            }
                            return null;
                          },
                        ),
                      ),
                      Padding(
                        padding: EdgeInsets.all(8.0),
                        child: InputText(
                          label: 'Valor:',
                          fontSize:
                              Responsive.dp(Responsive.istablet ? 1.2 : 1.6),
                          onChanged: (String text) {
                            _detailValue = text;
                          },
                          validator: (text) {
                            if (text!.length == 0) {
                              return "* Campo requerido";
                            }
                            return null;
                          },
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Consumer<ItemViewModel>(
                          builder: (context, model, child) => TextButton(
                            child: Text("ACEPTAR"),
                            onPressed: () {
                              if (_formItemDetailKey.currentState!.validate()) {
                                _formItemDetailKey.currentState!.save();
                                model.addItemDetail(
                                  _detailDescription,
                                  _detailValue,
                                );
                                Navigator.of(context).pop();
                              }
                            },
                          ),
                        ),
                      )
                    ],
                  ),
                ),
              ],
            ),
          );
        });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      constraints: BoxConstraints(
        minWidth: 250,
        maxWidth: Responsive.istablet ? 430 : 350,
      ),
      child: Column(
        children: [
          SizedBox(
            height: 8,
          ),
          CategorySpinner(),
          Form(
            key: _formKey,
            child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: Consumer<ItemViewModel>(
                builder: (context, model, child) => InputText(
                  label: 'Descripción:',
                  value: model.getDescription,
                  fontSize: Responsive.dp(Responsive.istablet ? 1.2 : 1.6),
                  onChanged: (String text) {
                    model.setDescription = text;
                  },
                  validator: (text) {
                    if (text!.length == 0) {
                      return "* Campo requerido";
                    }
                    return null;
                  },
                ),
              ),
            ),
          ),
          Row(
            children: [
              ItemQuantityWidget(),
              IconTextButton(
                icon: Icon(
                  Icons.add_box,
                ),
                label: 'Detalles',
                onChanged: _itemDetailDialogForm,
              ),
            ],
          ),
          SizedBox(
            height: 8,
          ),
          ItemDetailPanel(),
          SizedBox(
            height: 20,
          ),
          SizedBox(
            width: double.infinity,
            height: 50,
            child: Consumer3<CategoryViewModel, ItemViewModel,
                RequestDetailViewModel2>(
              builder: (
                context,
                categoryVM,
                itemVM,
                requestDetailVM,
                child,
              ) =>
                  TextButton(
                style: ButtonStyle(
                  backgroundColor: MaterialStateProperty.all(
                    Colors.teal,
                  ),
                  shape: MaterialStateProperty.all(
                    RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(25.0),
                    ),
                  ),
                ),
                //Para editar basta solo llenar los datos en los modelos y llamar a la ventana de solicitud de item
                onPressed: () async {
                  if (_formKey.currentState!.validate()) {
                    _formKey.currentState!.save();
                    Item _item = itemVM.getItem();
                    _item.category = categoryVM.getSelectedCategory();
                    requestDetailVM.addRequestDetail(
                      _item,
                      itemVM.getQuantity(),
                    );
                    itemVM.clearData();
                    _snackBar("Se ha añadido un Item");
                    Navigator.of(context).pop();
                  }
                },
                child: Text(
                  "REGISTRAR  ITEM",
                  style: TextStyle(color: Colors.white),
                ),
              ),
            ),
          )
        ],
      ),
    );
  }
}
