import 'package:arupo_shop/models/request_detail.dart';
import 'package:arupo_shop/view_models/request_detail_view_model.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class RequestDetailItem extends StatelessWidget {
  final RequestDetail detail;
  final int index;

  const RequestDetailItem({
    Key? key,
    required this.detail,
    required this.index,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final detailViewModel = Provider.of<RequestDetailViewModel>(context);

    var title = Text(
      detail.description,
      style: TextStyle(
        fontWeight: FontWeight.bold,
      ),
    );

    var subTitle = Row(
      children: <Widget>[
        Container(
          margin: const EdgeInsets.only(left: 0.0),
          child: Text(
            detail.value,
            style: TextStyle(
              color: Colors.teal,
            ),
          ),
        ),
      ],
    );

    return Column(
      children: <Widget>[
        ListTile(
          contentPadding: const EdgeInsets.symmetric(horizontal: 20.0),
          leading: Icon(
            Icons.assignment_outlined,
            color: Colors.teal,
          ),
          title: title,
          subtitle: subTitle,
          trailing: GestureDetector(
            child: new Icon(
              Icons.delete,
              color: Colors.red,
            ),
            onTap: () {
              _showAlertDialog(
                  context,
                  detailViewModel,
                  'Status',
                  '¿Eliminar el detalle ${detailViewModel.getDetail(index).description.toUpperCase()} ?',
                  index);
            },
          ),
        ),
        Divider(),
      ],
    );
  }

  void _showAlertDialog(
      context, model, String title, String message, int index) {
    AlertDialog alertDialog = AlertDialog(
      title: new Icon(
        Icons.warning,
        size: 80.0,
        color: Colors.amber,
      ),
      content: Text(message),
      actions: <Widget>[
        TextButton(
          child: Text(
            'ACEPTAR',
            style: TextStyle(
              color: Colors.red,
            ),
          ),
          onPressed: () {
            model.removeDetail(index);
            Navigator.of(context).pop();
          },
        ),
        TextButton(
          child: Text('CANCELAR'),
          onPressed: () {
            Navigator.of(context).pop();
          },
        ),
      ],
    );
    showDialog(context: context, builder: (_) => alertDialog);
  }
}
