import 'package:arupo_shop/constants/constants.dart';
import 'package:arupo_shop/models/request_detail2.dart';
import 'package:arupo_shop/view_models/category_view_model.dart';
import 'package:arupo_shop/view_models/item_view_model.dart';
import 'package:arupo_shop/view_models/request_detaill_view_model2.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class RequestDetailWidget extends StatelessWidget {
  final RequestDetail2 detail;
  final int index;

  const RequestDetailWidget({
    Key? key,
    required this.detail,
    required this.index,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    var title = Text(
      detail.item.description,
      style: TextStyle(
        fontWeight: FontWeight.bold,
      ),
    );

    var subTitle = Column(
      children: [
        Row(
          children: <Widget>[
            Container(
              margin: const EdgeInsets.only(left: 0.0),
              child: Text(
                "Cantidad: ${detail.quantity}",
                style: TextStyle(
                  color: Colors.teal,
                ),
              ),
            ),
            Container(
                margin: const EdgeInsets.symmetric(horizontal: 10),
                child: Text("Detalles: ${detail.item.itemDetails.length}"))
          ],
        ),
        Row(
          children: [
            Container(
              child: Text(detail.item.category.description),
            )
          ],
        )
      ],
    );

    return Column(
      children: <Widget>[
        Consumer3<RequestDetailViewModel2, ItemViewModel, CategoryViewModel>(
          builder: (context, requestDetailVM, itemVM, categoryVM, child) =>
              GestureDetector(
            child: ListTile(
              contentPadding: const EdgeInsets.symmetric(horizontal: 20.0),
              leading: Icon(
                Icons.assignment_outlined,
                color: Colors.teal,
              ),
              title: title,
              subtitle: subTitle,
              trailing: GestureDetector(
                child: new Icon(
                  Icons.delete_forever,
                  color: Colors.red,
                  size: 28,
                ),
                onTap: () {
                  _showAlertDialog(
                      context,
                      requestDetailVM,
                      'Status',
                      '¿Eliminar ${requestDetailVM.getRequestDetail(index).item.description.toUpperCase()} ?',
                      index);
                },
              ),
            ),
            onTap: () {
              //To edit
              itemVM.setData(
                requestDetailVM.getRequestDetail(index).item,
                itemVM.getQuantity(),
              );
              categoryVM.selectCategory(
                  requestDetailVM.getRequestDetail(index).item.category.id);
              requestDetailVM.setInEdition(index);
              Navigator.of(context).pushNamed(ITEM_ADD_SCREEN);
            },
          ),
        ),
        Divider(),
      ],
    );
  }

  void _showAlertDialog(
    context,
    RequestDetailViewModel2 model,
    String title,
    String message,
    int index,
  ) {
    AlertDialog alertDialog = AlertDialog(
      title: new Icon(
        Icons.warning,
        size: 70.0,
        color: Colors.amber,
      ),
      content: Text(message),
      actions: <Widget>[
        TextButton(
          child: Text(
            'ACEPTAR',
            style: TextStyle(
              color: Colors.red,
            ),
          ),
          onPressed: () {
            model.removeRequestDetail(index);
            Navigator.of(context).pop();
          },
        ),
        TextButton(
          child: Text('CANCELAR'),
          onPressed: () {
            Navigator.of(context).pop();
          },
        ),
      ],
    );
    showDialog(context: context, builder: (_) => alertDialog);
  }
}
