import 'package:arupo_shop/models/request.dart';
import 'package:arupo_shop/view_models/request_view_model.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class RequestItem extends StatelessWidget {
  final Request request;
  final int index;

  const RequestItem({Key? key, required this.request, required this.index})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    final requestViewModel = Provider.of<RequestViewModel>(context);
    var title = Text(
      request.getItemsDescription(),
      style: TextStyle(
        fontWeight: FontWeight.bold,
      ),
    );

    var subTitle = Column(
      children: [
        Row(
          children: <Widget>[
            Container(
              margin: const EdgeInsets.only(left: 0.0),
              child: Text(
                'Items: ${request.requestDetails.length.toString()}',
                style: TextStyle(
                  color: Colors.teal,
                ),
              ),
            ),
          ],
        ),
        Row(
          children: [Text("Fecha: ${request.date}")],
        )
      ],
    );

    return Column(
      children: <Widget>[
        ListTile(
          contentPadding: const EdgeInsets.symmetric(horizontal: 15.0),
          leading: Icon(
            Icons.assignment_outlined,
            color: Colors.teal,
          ),
          title: title,
          subtitle: subTitle,
          trailing: GestureDetector(
            child: new Icon(
              Icons.delete,
              color: Colors.red,
            ),
            onTap: () {
              _showAlertDialog(
                context,
                requestViewModel,
                'Status',
                '¿Eliminar la solicitud de ${request.getItemsDescription()} ?',
                request,
              );
            },
          ),
        ),
        Divider(),
      ],
    );
  }

  void _showAlertDialog(context, RequestViewModel model, String title,
      String message, Request selectedRequest) {
    AlertDialog alertDialog = AlertDialog(
      title: new Icon(
        Icons.warning,
        size: 80.0,
        color: Colors.amber,
      ),
      content: Text(message),
      actions: <Widget>[
        TextButton(
          child: Text(
            'ACEPTAR',
            style: TextStyle(
              color: Colors.red,
            ),
          ),
          onPressed: () {
            model.deleteRequest(selectedRequest);
            Navigator.of(context).pop();
          },
        ),
        TextButton(
          child: Text('CANCELAR'),
          onPressed: () {
            Navigator.of(context).pop();
          },
        ),
      ],
    );
    showDialog(context: context, builder: (_) => alertDialog);
  }
}
