import 'package:arupo_shop/models/request.dart';
import 'package:arupo_shop/screens/no_internet.dart';
import 'package:arupo_shop/view_models/auth_view_model.dart';
import 'package:arupo_shop/view_models/request_view_model.dart';
import 'package:arupo_shop/widgets/request_item.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class RequestList extends StatelessWidget {
  const RequestList({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final requestViewModel = Provider.of<RequestViewModel>(context);
    final authViewModel = Provider.of<AuthViewModel>(context);

    final Future<List<Request>> _fRequests =
        requestViewModel.getRequestListByBuyer(authViewModel.account);

    return FutureBuilder<List<Request>>(
      future: _fRequests,
      builder: (context, snapshot) {
        if (snapshot.connectionState != ConnectionState.done) {
          return Center(child: CircularProgressIndicator());
          // return: show loading widget
        }
        if (snapshot.hasError) {
          print(snapshot.error);
          // return: show error widget
          return NoInternetConnection(
            action: () async {
              // await requestViewModel.getRequestListByBuyer(authViewModel.account);
            },
          );
        }
        var requests = snapshot.data ?? [];
        return ListView.builder(
          shrinkWrap: true,
          itemCount: requests.length,
          itemBuilder: (context, index) {
            Request request = requests[index];
            return RequestItem(
              request: request,
              index: index,
            );
          },
        );
      },
    );
  }
}
