import 'package:arupo_shop/constants/constants.dart';
import 'package:arupo_shop/utils/responsive.dart';
import 'package:arupo_shop/utils/validator.dart';
import 'package:arupo_shop/view_models/auth_view_model.dart';
import 'package:arupo_shop/widgets/input_text.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class SigInForm extends StatefulWidget {
  const SigInForm({Key? key}) : super(key: key);

  @override
  _LoginFormState createState() => _LoginFormState();
}

class _LoginFormState extends State<SigInForm> {
  GlobalKey<FormState> _fomKey = GlobalKey();
  String _email = '', _password = '';

  _submit(AuthViewModel authViewModel) async {
    final isFormOk = _fomKey.currentState!.validate();
    if (isFormOk) {
      //API call
      await authViewModel.signIn(_email, _password);
      if (authViewModel.isAuthenticated) {
        if (authViewModel.account.credentials.length > 1) {
          Navigator.of(context).pushNamedAndRemoveUntil(
              ROLE_SCREEN, (Route<dynamic> route) => false);
        } else {
          String roleName =
              authViewModel.account.credentials[0].role.description;
          print(roleName);
          if (roleName == 'COMPRADOR') {
            Navigator.of(context).pushReplacementNamed(HOME_BUYER);
          } else {
            Navigator.of(context).pushReplacementNamed(HOME_SELLER);
          }
        }
      } else {
        _snackBar("LOGIN ERROR");
      }
    }
  }

  _snackBar(String text) {
    final snackBar = SnackBar(
      content: Text(text),
      action: SnackBarAction(
        label: '',
        onPressed: () {
          // Some code to undo the change.
        },
      ),
    );
    ScaffoldMessenger.of(context).showSnackBar(snackBar);
  }

  @override
  Widget build(BuildContext context) {
    //final Responsive responsive = Responsive.of(context);
    final authViewModel = Provider.of<AuthViewModel>(context);
    return Positioned(
      bottom: Responsive.hp(7),
      child: Container(
        constraints: BoxConstraints(
          minWidth: 250,
          maxWidth: Responsive.istablet ? 430 : 350,
        ),
        child: Form(
          //Importante asignar key
          key: this._fomKey,
          child: Column(
            children: <Widget>[
              InputText(
                label: 'Correo electrónico',
                keyboardType: TextInputType.emailAddress,
                fontSize: Responsive.dp(Responsive.istablet ? 1.2 : 1.6),
                onChanged: (String text) {
                  this._email = text;
                },
                validator: (text) {
                  if (text!.length == 0) {
                    return "* Campo requerido";
                  } else if (!Validate.isValidEmail(text)) {
                    return "Formato de correo incorrecto";
                  }
                  return null;
                },
              ),
              Container(
                decoration: BoxDecoration(
                  border: Border(
                    bottom: BorderSide(
                      color: Colors.teal,
                    ),
                  ),
                ),
                child: Row(
                  children: <Widget>[
                    //Necesario para que calcule el tamaño y se visualice el InputText
                    Expanded(
                      child: InputText(
                        label: 'Contraseña',
                        obscuredText: true,
                        borderEnabled: false,
                        fontSize:
                            Responsive.dp(Responsive.istablet ? 1.2 : 1.6),
                        onChanged: (String text) {
                          this._password = text;
                        },
                        validator: (text) {
                          if (text!.length == 0) {
                            return "* Campo requerido";
                          }
                          return null;
                        },
                      ),
                    ),
                    TextButton(
                      onPressed: () {},
                      child: Padding(
                        padding: EdgeInsets.symmetric(vertical: 5),
                        child: Text(
                          "Recuperar contraseña",
                          style: TextStyle(
                            color: Colors.teal,
                            fontWeight: FontWeight.bold,
                            fontSize:
                                Responsive.dp(Responsive.istablet ? 1.2 : 1.6),
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              SizedBox(
                height: Responsive.dp(4),
              ),
              SizedBox(
                width: double.infinity,
                child: TextButton(
                  style: ButtonStyle(
                    backgroundColor:
                        MaterialStateProperty.all(Colors.pinkAccent),
                  ),
                  //onPressed: this._submit(authViewModel),
                  onPressed: () {
                    _submit(authViewModel);
                  },
                  child: Text(
                    "Ingresar",
                    style: TextStyle(
                      color: Colors.lime[100],
                      fontSize: Responsive.dp(Responsive.istablet ? 1.2 : 1.8),
                    ),
                  ),
                ),
              ),
              SizedBox(
                height: Responsive.hp(4),
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[
                  Text(
                    "No tienes una cuenta?",
                    style: TextStyle(
                      fontSize: Responsive.dp(Responsive.istablet ? 1.2 : 1.6),
                    ),
                  ),
                  TextButton(
                    onPressed: () {
                      Navigator.of(context).pushNamed(SIGN_UP);
                    },
                    child: Padding(
                      padding: EdgeInsets.symmetric(vertical: 5),
                      child: Text("Registrame",
                          style: TextStyle(
                            color: Colors.pinkAccent,
                            fontWeight: FontWeight.bold,
                            fontSize:
                                Responsive.dp(Responsive.istablet ? 1.2 : 1.6),
                          )),
                    ),
                  ),
                ],
              ),
              SizedBox(
                height: Responsive.dp(15),
              )
            ],
          ),
        ),
      ),
    );
  }
}
