import 'package:arupo_shop/constants/constants.dart';
import 'package:arupo_shop/utils/responsive.dart';
import 'package:arupo_shop/utils/validator.dart';
import 'package:arupo_shop/view_models/role_view_model.dart';
import 'package:arupo_shop/view_models/user_view_model.dart';
import 'package:arupo_shop/widgets/input_text.dart';
import 'package:arupo_shop/widgets/role_spinner.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class SignUpForm extends StatefulWidget {
  const SignUpForm({Key? key}) : super(key: key);

  @override
  _SignUpFormState createState() => _SignUpFormState();
}

class _SignUpFormState extends State<SignUpForm> {
  static GlobalKey<FormState> _fomKey = GlobalKey();
  String _firstName = '';
  String _lastName = '';
  String _email = '';
  String _password = '';
  int _roleId = 0;

  late var _userViewModel;
  late var _roleViewModel;

  _submit(viewModel) async {
    final isFormOk = _fomKey.currentState!.validate();
    if (isFormOk) {
      //API call
      int idCreated = await viewModel.createUser(
        _roleId,
        _firstName,
        _lastName,
        _email,
        _password,
      );
      if (idCreated != 0) {
        _snackBar("REGISTRO EXITOSO");
        Navigator.of(context)
            .pushNamedAndRemoveUntil(SIGN_IN, (Route<dynamic> route) => false);
      } else {
        _snackBar("ERROR EN EL REGISTRO");
      }
    }
  }

  _snackBar(String text) {
    final snackBar = SnackBar(
      content: Text(text),
      action: SnackBarAction(
        label: '',
        onPressed: () {
          // Some code to undo the change.
        },
      ),
    );
    ScaffoldMessenger.of(context).showSnackBar(snackBar);
  }

  @override
  void initState() {
    _userViewModel = Provider.of<UserViewModel>(context, listen: false);
    _roleViewModel = Provider.of<RoleViewModel>(context, listen: false);
    _roleId = _roleViewModel.roleIdSelected;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    //final _userViewModel = Provider.of<UserViewModel>(context, listen: false);
    //final _roleViewModel = Provider.of<RoleViewModel>(context, listen: false);

    return Positioned(
      bottom: Responsive.hp(8),
      child: Container(
        constraints: BoxConstraints(
          minWidth: 250,
          maxWidth: Responsive.istablet ? 430 : 350,
        ),
        child: Form(
          //Importante asignar key
          key: _fomKey,
          child: Column(
            children: <Widget>[
              RoleSpinner(),
              InputText(
                label: 'Nombre',
                validator: (text) {
                  if (text!.length == 0) {
                    return "* Campo requerido";
                  }
                  return null;
                },
                onChanged: (String text) {
                  this._firstName = text;
                },
              ),
              InputText(
                label: 'Apellido',
                validator: (text) {
                  if (text!.length == 0) {
                    return "* Campo requerido";
                  }
                  return null;
                },
                onChanged: (String text) {
                  this._lastName = text;
                },
              ),
              InputText(
                label: 'Correo electrónico',
                keyboardType: TextInputType.emailAddress,
                fontSize: Responsive.dp(Responsive.istablet ? 1.2 : 1.6),
                onChanged: (String text) {
                  this._email = text;
                },
                validator: (text) {
                  if (text!.length == 0) {
                    return "* Campo requerido";
                  } else if (!Validate.isValidEmail(text)) {
                    return "Formato de correo incorrecto";
                  }
                  return null;
                },
              ),
              InputText(
                label: 'Contraseña',
                obscuredText: true,
                validator: (text) {
                  if (text!.length == 0) {
                    return "* Campo requerido";
                  }
                  return null;
                },
                onChanged: (String text) {
                  this._password = text;
                },
              ),
              SizedBox(
                height: Responsive.dp(4),
              ),
              SizedBox(
                width: double.infinity,
                child: TextButton(
                  style: ButtonStyle(
                    backgroundColor:
                        MaterialStateProperty.all(Colors.pinkAccent),
                  ),
                  onPressed: () {
                    _submit(_userViewModel);
                  },
                  child: Text(
                    "Registrarme",
                    style: TextStyle(
                      color: Colors.lime[100],
                      fontSize: Responsive.dp(Responsive.istablet ? 1.2 : 1.8),
                    ),
                  ),
                ),
              ),
              TextButton(
                onPressed: () {
                  Navigator.of(context).pushNamedAndRemoveUntil(
                      SIGN_IN, (Route<dynamic> route) => false);
                },
                child: Padding(
                  padding: EdgeInsets.symmetric(vertical: 5),
                  child: Text("Iniciar Sesión",
                      style: TextStyle(
                        color: Colors.pinkAccent,
                        fontWeight: FontWeight.bold,
                        fontSize:
                            Responsive.dp(Responsive.istablet ? 1.2 : 1.6),
                      )),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
